==> aliyun-python-sdk-eflo-controller-1.0.1.tar.gz: aliyun-python-sdk-eflo-controller-1.0.1/aliyunsdkeflo_controller/request/v20221215/RebootNodesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
import json

class RebootNodesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'eflo-controller', '2022-12-15', 'RebootNodes','eflo')
		self.set_method('POST')

	def get_IgnoreFailedNodeTasks(self): # Boolean
		return self.get_body_params().get('IgnoreFailedNodeTasks')

	def set_IgnoreFailedNodeTasks(self, IgnoreFailedNodeTasks):  # Boolean
		self.add_body_params('IgnoreFailedNodeTasks', IgnoreFailedNodeTasks)
	def get_ClusterId(self): # String
		return self.get_body_params().get('ClusterId')

	def set_ClusterId(self, ClusterId):  # String
		self.add_body_params('ClusterId', ClusterId)
	def get_Nodes(self): # Array
		return self.get_body_params().get('Nodes')

	def set_Nodes(self, Nodes):  # Array
		self.add_body_params("Nodes", json.dumps(Nodes))

==> aliyun-python-sdk-eflo-controller-1.0.3.tar.gz: aliyun-python-sdk-eflo-controller-1.0.3/aliyunsdkeflo_controller/request/v20221215/RebootNodesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
import json

class RebootNodesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'eflo-controller', '2022-12-15', 'RebootNodes')
		self.set_method('POST')

	def get_IgnoreFailedNodeTasks(self): # Boolean
		return self.get_body_params().get('IgnoreFailedNodeTasks')

	def set_IgnoreFailedNodeTasks(self, IgnoreFailedNodeTasks):  # Boolean
		self.add_body_params('IgnoreFailedNodeTasks', IgnoreFailedNodeTasks)
	def get_ClusterId(self): # String
		return self.get_body_params().get('ClusterId')

	def set_ClusterId(self, ClusterId):  # String
		self.add_body_params('ClusterId', ClusterId)
	def get_Nodes(self): # Array
		return self.get_body_params().get('Nodes')

	def set_Nodes(self, Nodes):  # Array
		self.add_body_params("Nodes", json.dumps(Nodes))
